/*
	utility program for the ProWesS loader

	CBUTTON : put a button in the button frame
	when button is indicated with a DO, start chosen program
	possible command line parameters :
		-path XXX : searchpath for loader file
		-name XXX : name inside button
		-insert : ask for user to insert the disk first
		XXX : name of loader file which starts the program (obligatory)
	if no name is given, then the name of the loader file will be displayed
	ERR_IPAR will be returned if no filename is given

	written by Joachim Van der Auwera for PROGS
	(c) 1996 by PROGS, Professional & Graphical Software
	started 30 March 1996
*/

#include "str_h"
#include "thing_h"
#include "ProWesS_h"

#define catch(x) if (err=(x)) return err; else
Error start(PWObject object);

typedef struct {
	char *name, *path, *file;
	char insert;
} Global;

Error init(char *param)
{
	Error err;
	char **params;
	int i;
	PWObject obj;
	Global g;

	MEMClear(sizeof(Global),&g);
	g.path="$D;$P";

	/* pars the command line parameters */
	catch( STRBreak(param,&params) );
	for (i=0 ; params[i] ; i++)
	{
		if (STRSameCI("-path",params[i]))
		{
			if (params[i+1])
				g.path=params[++i];
			else
				return ERR_IPAR;
		}
		else
		if (STRSameCI("-name",params[i]))
		{
			if (params[i+1])
				g.name=params[++i];
			else
				return ERR_IPAR;
		}
		else
		if (STRSameCI("-insert",params[i]))
			g.insert=TRUE;
		else
			g.file=params[i];
	}
	if (!g.file) return ERR_IPAR;
	if (!g.name) g.name=g.file;

	/* now create the button */
	catch( PWCreate(NULL,&obj,PW_TYPE_LOOSE_ITEM,
					PW_LOOSE_TEXT, g.name,
					PW_LOOSE_ACTION_DO, start,
					PW_LOOSE_CHANGE_STATUS, FALSE,
					PW_WINDOW_BUTTON,
					PW_OBJECT_AUXILIARY, &g,
					NULL) );
	return PWActivate(obj);
}

Error start(PWObject object)
{
	Error err;
	Global *g;
	char *strs[3];

	PWQuery(object,PW_OBJECT_AUXILIARY,&g);

	if (g->insert)
	{
		strs[0]="Please insert disk to load";
		strs[1]=g->name;
		catch( THINGExec("request",8,MYSELF,TRUE,2,strs,0,NULL,NULL) );
	}

	strs[0]="-path";
	strs[1]=g->path;
	strs[2]=g->file;
	if (THINGExec("ProWesS loader",8,MYSELF,TRUE,3,strs,0,NULL,NULL))
	{
		strs[0]="Unable to start";
		strs[1]=g->name;
		catch( THINGExec("request",8,MYSELF,FALSE,2,strs,0,NULL,NULL) );
	}
	return ERR_OK;
}
