/*
	utility program for the ProWesS loader

	WAIT : wait for a certain period or until a certain thing exists
	this program accepts two parameters : a thingname and a maximum waiting
	period (preceded by -wait). The program returns when the thing exists, or
	the waiting period has elapsed. If no waiting period is specified, the
	program will wait indefinately. The wait period is given in a unit of
	approximately 1/50s.

	written by Joachim Van der Auwera for PROGS
	(c) 1996 by PROGS, Professional & Graphical Software
	started 09 January 1996
	21.10.2000 fixed problem when waiting for thing (was an undefined timeout)
*/

#include "str.h"
#include "mem.h"
#include "io.h"
#include "thing.h"

#define catch(x) if (err=(x)) return err; else

Error init(char *param)
{
	Error err;
	char **params;
	char *thing;
	Thing dummy;
	int i, wait=-1;

	/* pars the command line parameters */
	catch( STRBreak(param,&params) );
	for (i=0 ; params[i] ; i++)
	{
		if (STRSameCI("-path",params[i]))
		{
			if (params[i+1])
				i++;
			else
				return ERR_IPAR;
		}
		else
		if (STRSameCI("-wait",params[i]))
		{
			if (params[i+1])
			{
				STRFormatGet(params[++i],NULL,"%d",&wait);
				if (wait<0) wait=0;
			}
			else
				return ERR_IPAR;
		}
		else
			thing=params[i];
	}

	while (wait)
	{
		if (thing)
		{
			err=THINGUse(thing,0,&dummy,NULL);
			if (!err) return ERR_OK;
		}
		JOBSuspend(MYSELF,1,NULL);
		if (wait>0) wait--;
	}
	return ERR_OK;
}
